@@ -1,5 +1,5 @@
 ##    pywebsite - Python Website Library
-##    Copyright (C) 2009 Rene Dudfield
+##    Copyright (C) 2009, 2010 Rene Dudfield
 ##
 ##    This library is free software; you can redistribute it and/or
 ##    modify it under the terms of the GNU Library General Public
@@ -202,54 +202,3 @@ class ImageOps(object):
         
         return cached_fname
 
-
-#class AspectSize(object):
-#
-#    def size(self, orig_width, orig_height, 
-#aspect_width = 0, keep_aspect_height = 0):
-#        """
-#        >>> size(10,44)
-#        """
-
-def resize_percent(width, height, percent_width, percent_height):
-    """ resize_percent(width, height, percent_width, percent_height)
-        Returns a (width, height) scaled by the percentages given.
-    >>> resize_percent(100, 100, 50, 50)
-    (50, 50)
- 
-    >>> sizes = ((100, 100, 50, 50), (100, 100, 200, 50), 
-    ...          (100, 100, 200, 0))
-    >>> for s in sizes:
-    ...     print (resize_percent(*s))
-    (50, 50)
-    (200, 50)
-    (200, 0)
-    """
-    return int((percent_width*width)/100), int((percent_height*height)/100)
-
-
-def resize_aspect(width, height, wanted_width = None, wanted_height = None):
-    """ returns the (width, height)
-    >>> resize_aspect(100, 120, None, 60)
-    (50, 60)
-    """
-    
-    if wanted_width is None and wanted_height is None:
-        raise ValueError("must give a wanted width and height")
-
-    # get the aspect ratio of the image.
-
-
-
-
-
-
-
-if __name__ == "__main__":
-    
-    
-    import doctest, sys
-    if "test" in sys.argv:
-        doctest.testmod() 
-    
-    
